==> ejc-outcontract-api-3.0.0-20220726.023647-95-sources.jar: com/ejianc/foundation/outcontract/vo/ChangeOutcontractEquipmentRentVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 变更租金明细表
 * 
 * @author generator
 * 
 */
public class ChangeOutcontractEquipmentRentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long changeOutcontractId; // 变更合同id
    private Long equipmentId; // 物资id
    private Long equipmentCategoryId; // 物资分类id
    private String equipmentCategoryName; // 物资分类名称
    private String equipmentCategoryCode; // 物资分类编码
    private String equipmentCode; // 物资编码
    private String equipmentName; // 物资名称
    private String equipmentSpec; // 规格型号
    private String equipmentUnit; // 计量单位
    private Integer quantity; // 台数
    private BigDecimal taxRate; // 税率（%）
    private BigDecimal totalPrice; // 合价
    private BigDecimal leaseTerm; // 租赁期（天）
    private BigDecimal untaxUnitPrice; // 不含税单价
    private BigDecimal taxUnitPrice; // 含税单价
    private String remark; // 备注
    
    private String errorMsg; // 导入错误信息
    

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Long getEquipmentCategoryId() {
        return equipmentCategoryId;
    }

    public void setEquipmentCategoryId(Long equipmentCategoryId) {
        this.equipmentCategoryId = equipmentCategoryId;
    }
    public String getEquipmentCategoryName() {
        return equipmentCategoryName;
    }

    public void setEquipmentCategoryName(String equipmentCategoryName) {
        this.equipmentCategoryName = equipmentCategoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentSpec() {
        return equipmentSpec;
    }

    public void setEquipmentSpec(String equipmentSpec) {
        this.equipmentSpec = equipmentSpec;
    }
    public String getEquipmentUnit() {
        return equipmentUnit;
    }

    public void setEquipmentUnit(String equipmentUnit) {
        this.equipmentUnit = equipmentUnit;
    }
    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getErrorMsg() {
		return errorMsg;
	}

	public void setErrorMsg(String errorMsg) {
		this.errorMsg = errorMsg;
	}

	public String getEquipmentCategoryCode() {
		return equipmentCategoryCode;
	}

	public void setEquipmentCategoryCode(String equipmentCategoryCode) {
		this.equipmentCategoryCode = equipmentCategoryCode;
	}
}

==> ejc-outcontract-api-3.0.0-20251022.020546-380-sources.jar: com/ejianc/foundation/outcontract/vo/ChangeOutcontractEquipmentRentVO.java <==
package com.ejianc.foundation.outcontract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 变更租金明细表
 * 
 * @author generator
 * 
 */
public class ChangeOutcontractEquipmentRentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long changeOutcontractId; // 变更合同id
    private Long equipmentId; // 物资id
    private Long equipmentCategoryId; // 物资分类id
    private String equipmentCategoryName; // 物资分类名称
    private String equipmentCategoryCode; // 物资分类编码
    private String equipmentCode; // 物资编码
    private String equipmentName; // 物资名称
    private String equipmentSpec; // 规格型号
    private String equipmentUnit; // 计量单位
    private Integer quantity; // 台数
    private BigDecimal taxRate; // 税率（%）
    private BigDecimal totalPrice; // 合价
    private BigDecimal leaseTerm; // 租赁期（天）
    private BigDecimal untaxUnitPrice; // 不含税单价
    private BigDecimal taxUnitPrice; // 含税单价
    private String remark; // 备注
    
    private String errorMsg; // 导入错误信息

    private String yzwSkuNo; // 云筑网物资编码

    public String getYzwSkuNo() {
        return yzwSkuNo;
    }

    public void setYzwSkuNo(String yzwSkuNo) {
        this.yzwSkuNo = yzwSkuNo;
    }

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Long getEquipmentCategoryId() {
        return equipmentCategoryId;
    }

    public void setEquipmentCategoryId(Long equipmentCategoryId) {
        this.equipmentCategoryId = equipmentCategoryId;
    }
    public String getEquipmentCategoryName() {
        return equipmentCategoryName;
    }

    public void setEquipmentCategoryName(String equipmentCategoryName) {
        this.equipmentCategoryName = equipmentCategoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentSpec() {
        return equipmentSpec;
    }

    public void setEquipmentSpec(String equipmentSpec) {
        this.equipmentSpec = equipmentSpec;
    }
    public String getEquipmentUnit() {
        return equipmentUnit;
    }

    public void setEquipmentUnit(String equipmentUnit) {
        this.equipmentUnit = equipmentUnit;
    }
    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getErrorMsg() {
		return errorMsg;
	}

	public void setErrorMsg(String errorMsg) {
		this.errorMsg = errorMsg;
	}

	public String getEquipmentCategoryCode() {
		return equipmentCategoryCode;
	}

	public void setEquipmentCategoryCode(String equipmentCategoryCode) {
		this.equipmentCategoryCode = equipmentCategoryCode;
	}
}
